@@ -2,7 +2,7 @@ package ExtUtils::Typemaps;
 use 5.006001;
 use strict;
 use warnings;
-our $VERSION = '3.29_01';
+our $VERSION = '3.36';
 
 require ExtUtils::ParseXS;
 require ExtUtils::ParseXS::Constants;
@@ -22,7 +22,7 @@ ExtUtils::Typemaps - Read/Write/Modify Perl/XS typemap files
   # $typemap = ExtUtils::Typemaps->new();
   # alternatively create an in-memory typemap by parsing a string
   # $typemap = ExtUtils::Typemaps->new(string => $sometypemap);
-  
+
   # add a mapping
   $typemap->add_typemap(ctype => 'NV', xstype => 'T_NV');
   $typemap->add_inputmap(
@@ -33,13 +33,13 @@ ExtUtils::Typemaps - Read/Write/Modify Perl/XS typemap files
   );
   $typemap->add_string(string => $typemapstring);
                                            # will be parsed and merged
-  
+
   # remove a mapping (same for remove_typemap and remove_outputmap...)
   $typemap->remove_inputmap(xstype => 'SomeType');
-  
+
   # save a typemap to a file
   $typemap->write(file => 'anotherfile.map');
-  
+
   # merge the other typemap into this one
   $typemap->merge(typemap => $another_typemap);
 
@@ -536,7 +536,7 @@ sub get_outputmap {
 
 Write the typemap to a file. Optionally takes a C<file> argument. If given, the
 typemap will be written to the specified file. If not, the typemap is written
-to the currently stored file name (see C<-E<gt>file> above, this defaults to the file
+to the currently stored file name (see L</file> above, this defaults to the file
 it was read from if any).
 
 =cut
@@ -782,7 +782,7 @@ corresponding OUTPUT code:
   ',
     'T_OUT' => '    {
             GV *gv = newGVgen("$Package");
-            if ( do_open(gv, "+>&", 3, FALSE, 0, 0, $var) )
+            if ( do_openn(gv, "+>&", 3, FALSE, 0, 0, $var, NULL, 0) )
                 sv_setsv(
                   $arg,
                   sv_bless(newRV((SV*)gv), gv_stashpv("$Package",1))
